==> haskell-enclosed-exceptions-1.0.3-341-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-enclosed-exceptions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 enclosed-exceptions
version:              1.0.3
visibility:           public
id:                   enclosed-exceptions-1.0.3-IYAdhoY9Uwle6cT0g97cl
key:                  enclosed-exceptions-1.0.3-IYAdhoY9Uwle6cT0g97cl
license:              MIT
maintainer:           jmacristovao@gmail.com, michael@snoyman.com
author:               Michael Snoyman, João Cristóvão
homepage:             https://github.com/jcristovao/enclosed-exceptions
synopsis:             Catching all exceptions from within an enclosed computation
description:
    Catching all exceptions raised within an enclosed computation,
    while remaining responsive to (external) asynchronous exceptions.
    For more information on the technique, please see:
    <https://www.fpcomplete.com/user/snoyberg/general-haskell/exceptions/catching-all-exceptions>

category:             Control
abi:                  266c1402e66b40e2d2ac59e58807649d
exposed:              True
exposed-modules:      Control.Exception.Enclosed
import-dirs:          /usr/lib/ghc-9.4.8/site-local/enclosed-exceptions-1.0.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/enclosed-exceptions-1.0.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/enclosed-exceptions-1.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-enclosed-exceptions
hs-libraries:         HSenclosed-exceptions-1.0.3-IYAdhoY9Uwle6cT0g97cl
depends:
    base-4.17.2.1 deepseq-1.4.8.0
    lifted-base-0.2.3.12-HP4xMxCJiI8CH51PxJNFnm
    monad-control-1.0.3.1-LvD2QGBgFgqFpndGGLy7SM transformers-0.5.6.2
    transformers-base-0.4.6-HugzaWq8ZFe99E7DUGbdeP

haddock-interfaces:
    /usr/share/doc/haskell-enclosed-exceptions/html/enclosed-exceptions.haddock

haddock-html:         /usr/share/doc/haskell-enclosed-exceptions/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-enclosed-exceptions-1.0.3-342-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-enclosed-exceptions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 enclosed-exceptions
version:              1.0.3
visibility:           public
id:                   enclosed-exceptions-1.0.3-8k3yVNXRxILK2FFbec2FLY
key:                  enclosed-exceptions-1.0.3-8k3yVNXRxILK2FFbec2FLY
license:              MIT
maintainer:           jmacristovao@gmail.com, michael@snoyman.com
author:               Michael Snoyman, João Cristóvão
homepage:             https://github.com/jcristovao/enclosed-exceptions
synopsis:             Catching all exceptions from within an enclosed computation
description:
    Catching all exceptions raised within an enclosed computation,
    while remaining responsive to (external) asynchronous exceptions.
    For more information on the technique, please see:
    <https://www.fpcomplete.com/user/snoyberg/general-haskell/exceptions/catching-all-exceptions>

category:             Control
abi:                  24875720bf7b188b411addc3e0613a5f
exposed:              True
exposed-modules:      Control.Exception.Enclosed
import-dirs:          /usr/lib/ghc-9.4.8/site-local/enclosed-exceptions-1.0.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/enclosed-exceptions-1.0.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/enclosed-exceptions-1.0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-enclosed-exceptions
hs-libraries:         HSenclosed-exceptions-1.0.3-8k3yVNXRxILK2FFbec2FLY
depends:
    base-4.17.2.1 deepseq-1.4.8.0
    lifted-base-0.2.3.12-K95KhxsU62vCEfDwRWfqIf
    monad-control-1.0.3.1-F7OGpFtdcoIGnChB30cAbG transformers-0.5.6.2
    transformers-base-0.4.6-2uAlFN9wTx3C7pJQeXk7KL

haddock-interfaces:
    /usr/share/doc/haskell-enclosed-exceptions/html/enclosed-exceptions.haddock

haddock-html:         /usr/share/doc/haskell-enclosed-exceptions/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
